# CLI program description

- CLI should display (1) Executive summary, (2) Bulk materials.

## [1] Executive Summary

- Total Capital Investment 54,990,000 $
- Operating Cost 30,374,000 $/yr
- Revenues 41,067,000 $/yr
- Batch Size 4,401.59 kg MP
- Cost Basis Annual Rate 1,368,895 kg MP/yr
- Unit Production Cost 22.19 $/kg MP
- Unit Production Revenue 30.00 $/kg MP
- Gross Margin 26.04 %
- Return On Investment 19.17 %
- Payback Time 5.22 years
- IRR (After Taxes) 13.98 %
- NPV (at 5.0% Interest) 63,432,000 $
- MP = Total Flow of Penicillin Product in 'Final Product' Stream

## [2] Bulk materials [kg/year] [kg/batch] [cost/kg]

- Acetone 473,342 1,522.000 0.346
- Air 104,832,791 337,082.930 76.582
- Butyl Acetate 275,153 884.737 0.201
- Glucose 6,729,107 21,637.000 4.916
- H2SO4 (10% w/w) 297,727 957.322 0.217
- H3PO4 5% 19,366,393 62,271.359 14.147
- Inno. Media 995 3.199 0.001
- NaOH (0.5 M) 17,759,194 57,103.518 12.973
- Pharmamedium 811,898 2,610.603 0.593
- PhenoxyAcAcid 964,100 3,100.000 0.704
- Sodium Acetate 31,100 100.000 0.023
- Sodium Hydroxid 174,727 561.822 0.128
- Trace metals 421,920 1,356.657 0.308
